@@ -5,9 +5,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-03-08'; # DATE
+our $DATE = '2022-04-15'; # DATE
 our $DIST = 'Perinci-Examples'; # DIST
-our $VERSION = '0.822'; # VERSION
+our $VERSION = '0.823'; # VERSION
 
 our %SPEC;
 
@@ -102,7 +102,7 @@ Perinci::Examples::ArgsAs - Demonstrate various values of `args_as` function met
 
 =head1 VERSION
 
-This document describes version 0.822 of Perinci::Examples::ArgsAs (from Perl distribution Perinci-Examples), released on 2022-03-08.
+This document describes version 0.823 of Perinci::Examples::ArgsAs (from Perl distribution Perinci-Examples), released on 2022-04-15.
 
 =head1 DESCRIPTION
 
@@ -236,7 +236,7 @@ Examples:
 
 =item * Without the optional arg3:
 
- args_as_hash(arg1 => "abc", arg2 => 10); # -> [200, "OK", ["arg2", 10, "arg1", "abc"], {}]
+ args_as_hash(arg1 => "abc", arg2 => 10); # -> [200, "OK", ["arg1", "abc", "arg2", 10], {}]
 
 =item * With the optional arg3:
 
@@ -244,7 +244,7 @@ Examples:
 
 Result:
 
- [200, "OK", ["arg2", 20, "arg3", 0.5, "arg1", "def"], {}]
+ [200, "OK", ["arg3", 0.5, "arg1", "def", "arg2", 20], {}]
 
 =back
 
